@@ -9,7 +9,7 @@ require 'time'
 require 'debci'
 require 'debci/app'
 require 'debci/job'
-require 'debci/key'
+require 'debci/user'
 require 'debci/test_handler'
 
 
@@ -80,7 +80,6 @@ module Debci
     end
 
     namespace '/v1' do
-
       doc <<-EOF
       * bli
       * bli
@@ -133,6 +132,12 @@ module Debci
       EOF
       get '/retry/:run_id' do
         if @user
+          run_id = params[:run_id]
+          begin
+            @original_job = Debci::Job.find(run_id)
+          rescue ActiveRecord::RecordNotFound => error
+            halt(404, "Job ID not known: #{run_id}")
+          end
           erb :retry
         else
           [403, erb(:cant_retry)]
@@ -234,7 +239,7 @@ module Debci
       EOF
       get '/test' do
         authenticate_key!
-        jobs = Debci::Job.where(requestor: @user)
+        jobs = Debci::Job.where(requestor: @user.username)
         if params[:since]
           since = Time.strptime(params[:since], '%s')
           jobs = jobs.where('updated_at >= ?', since)
@@ -247,14 +252,17 @@ module Debci
         data.to_json
       end
 
-      before '/test/:suite/:arch*'do
+      before '/test/:suite/:arch*' do
         authenticate_key!
         @suite = params[:suite]
         @arch = params[:arch]
+        @priority = params.fetch("priority", 1).to_i
         if !Debci.config.arch_list.include?(arch)
           halt(400, "Invalid architecture: #{arch}\n")
         elsif !Debci.config.suite_list.include?(suite)
           halt(400, "Invalid suite: #{suite}\n")
+        elsif !validate_priority(@priority)
+          halt(400, "Invalid priority: #{@priority}\n")
         end
       end
 
@@ -265,7 +273,7 @@ module Debci
         test_requests = load_json(params[:tests])
         errors = validate_batch_test(test_requests)
         if errors.empty?
-          request_batch_tests(test_requests, @user)
+          request_batch_tests(test_requests, @user, @priority)
           201
         else
           halt(400, "Error: #{errors.join("\n")}")
@@ -282,6 +290,8 @@ module Debci
 
       * `tests`: a JSON object decribing the tests to be executed. This parameter can
         be either a file upload or a regular POST parameter.
+      * `priority`: an integer between 1 and 10 describing the priority to assign the
+        requested tests
 
       The `tests` JSON object must be an *Array* of objects. Each object represents a
       single test request, and can contain the following keys:
@@ -330,15 +340,20 @@ module Debci
       $ curl --header "Auth-Key: $KEY" --form tests=@tests.json \
           https://host/api/v1/test/testing/amd64
 
-      # tests as a regular POST parameter
-      $ curl --header "Auth-Key: $KEY" --data="$(cat tests.json)" \
+      # tests as a regular POST parameter, with specific priority
+      $ curl --header "Auth-Key: $KEY" --data tests="$(cat tests.json)" --data priority=8 \
           https://host/api/v1/test/testing/amd64
       ```
       EOF
       post '/test/:suite/:arch' do
         tests = load_json(params[:tests])
-        self.request_tests(tests, suite, arch, @user)
-        201
+        errors = validate_tests(tests)
+        if errors.empty?
+          self.request_tests(tests, suite, arch, @user, @priority)
+          201
+        else
+          halt(400, "Invalid request: #{errors.join("\n")}")
+        end
       end
 
       doc <<-EOF
@@ -349,6 +364,8 @@ module Debci
       * `:suite`: which suite to test
       * `:arch`: which architecture to test
       * `:package`: which (source!) package to test
+      * `priority`: an integer between 1 and 10 describing the priority to assign the
+        requested tests
 
       Example:
 
@@ -364,17 +381,17 @@ module Debci
           halt(400, "Invalid package name: #{pkg}\n")
         end
 
+        package = Debci::Package.find_or_create_by!(name: pkg)
         job = Debci::Job.create!(
-            package: pkg,
+            package: package,
             suite: params[:suite],
             arch: params[:arch],
-            requestor: @user,
+            requestor: @user.username,
         )
-        self.enqueue(job)
+        self.enqueue(job, @priority)
 
         201
       end
-
     end
 
     protected
@@ -387,7 +404,7 @@ module Debci
       begin
         raise "No tests" if param.nil?
         str = param.is_a?(Hash) && File.read(param[:tempfile]) || param
-        JSON.load(str)
+        JSON.parse(str)
       rescue JSON::ParserError => error
         halt(400, "Invalid JSON: #{error}")
       rescue StandardError => error
@@ -398,7 +415,7 @@ module Debci
     def authenticate_key!
       key = env['HTTP_AUTH_KEY']
       if key && @user = Debci::Key.authenticate(key)
-        response['Auth-User'] = @user
+        response['Auth-User'] = @user.username
       else
         halt(403, "Invalid key\n")
       end
