@@ -15,9 +15,15 @@ module Debci
   #
   Config = Struct.new(
     :amqp_server,
+    :amqp_ssl,
+    :amqp_cacert,
+    :amqp_cert,
+    :amqp_key,
+    :amqp_results_queue,
     :arch,
     :arch_list,
     :artifacts_url_base,
+    :autopkgtest_basedir,
     :auth_fail_page,
     :backend,
     :config_dir,
@@ -29,6 +35,7 @@ module Debci
     :html_dir,
     :packages_dir,
     :pending_status_per_page,
+    :status_visible_days,
     :quiet,
     :secrets_dir,
     :sendmail_from,
@@ -38,9 +45,10 @@ module Debci
     :suite_list,
     :url_base,
   ) do
+    alias_method :data_retention, :data_retention_days
 
     # for development usage
-    if !ENV['ADTTMP']
+    if !ENV['AUTOPKGTEST_TMP']
       bin = File.dirname(__FILE__) + '/../../bin'
       if File.exists?(bin)
         ENV['PATH'] = [bin,ENV['PATH']].join(':')
@@ -51,6 +59,10 @@ module Debci
       @types ||= {
         /_list$/ => lambda { |x| x.split}, # Array
         'quiet' => lambda { |x| x == 'true' }, # boolean
+        'amqp_ssl' => lambda { |x| x == 'true' }, # boolean
+        'data_retention_days' => lambda { |x| x.to_i },
+        'status_visible_days' => lambda { |x| x.to_i },
+        'failing_packages_per_page' => lambda { |x| x.to_i },
       }
     end
 
@@ -74,7 +86,6 @@ module Debci
         end
       end
     end
-
   end
 
 end
