@@ -1,4 +1,3 @@
-require 'sinatra'
 require 'json'
 require 'kaminari/core'
 require 'kaminari/activerecord'
@@ -13,7 +12,7 @@ module Debci
     include Debci::TestHandler
     include Debci::HTMLHelpers
 
-    set :views, File.dirname(__FILE__) + '/html'
+    set :views, File.dirname(__FILE__) + '/html/templates'
 
     configure do
       set :suites, Debci.config.suite_list
@@ -36,14 +35,14 @@ module Debci
     end
 
     get '/' do
-      redirect("/user/#{@user}")
+      redirect("/user/#{@user.username}")
     end
 
     get '/login' do
       user = read_request_user
       if user
         session[:user] = user
-        redirect("/user/#{user}")
+        redirect("/user/#{user.username}")
       else
         content = "Unauthenticated!\n"
         content = File.read(Debci.config.auth_fail_page) if Debci.config.auth_fail_page
@@ -57,12 +56,12 @@ module Debci
     end
 
     get '/:user' do
-      redirect("/user/#{params[:user]}/jobs") unless @user == params[:user]
+      redirect("/user/#{params[:user]}/jobs") unless @user.username == params[:user]
       erb :self_service
     end
 
     get '/:user/test' do
-      redirect("/user/#{params[:user]}/jobs") unless @user == params[:user]
+      redirect("/user/#{params[:user]}/jobs") unless @user.username == params[:user]
       erb :self_service_test
     end
 
@@ -149,10 +148,8 @@ module Debci
       @history = Debci::Job.where(query)
 
       unless package_filter.empty?
-        @history = @history.where(
-          'package LIKE :query',
-          query: package_filter.tr('*', '%'),
-        )
+        pkgs = Debci::Package.where('name LIKE :query', query: package_filter.tr('*', '%')).pluck(:id)
+        @history = @history.where(package_id: pkgs)
       end
 
       unless trigger_filter.empty?
