@@ -8,6 +8,8 @@ describe Debci::API do
   include Rack::Test::Methods
   include Debci::TestHandler
 
+  include_context 'tmpdir'
+
   class API < Debci::API
     set :raise_errors, true
     set :show_exceptions, false
@@ -20,13 +22,12 @@ describe Debci::API do
   let(:suite) { Debci.config.suite }
   let(:arch) { Debci.config.arch }
 
-  before do
-    @tmpdir = Dir.mktmpdir
-    allow(Debci.config).to receive(:secrets_dir).and_return(@tmpdir)
+  let(:theuser) do
+    Debci::User.create!(username: 'theuser')
   end
 
-  after do
-    FileUtils.rm_rf(@tmpdir)
+  before do
+    allow(Debci.config).to receive(:secrets_dir).and_return(tmpdir)
   end
 
   context 'authentication' do
@@ -37,7 +38,7 @@ describe Debci::API do
     end
 
     it 'authenticates with a good key' do
-      key = Debci::Key.create!(user: 'theuser').key
+      key = Debci::Key.create!(user: theuser).key
 
       header 'Auth-Key', key
       get '/api/v1/auth'
@@ -60,7 +61,8 @@ describe Debci::API do
       post '/api/v1/getkey', {}, 'SSL_CLIENT_S_DN_CN' => 'foo@bar.com'
       expect(last_response.status).to eq(201)
 
-      key = Debci::Key.find_by(user: 'foo@bar.com')
+      user = Debci::User.find_by(username: 'foo@bar.com')
+      key = user.keys.first
       expect(key).to_not be_nil
     end
 
@@ -73,7 +75,7 @@ describe Debci::API do
 
   context 'receiving test requests' do
     before do
-      key = Debci::Key.create!(user: 'theuser').key
+      key = Debci::Key.create!(user: theuser).key
 
       header 'Auth-Key', key
     end
@@ -82,10 +84,10 @@ describe Debci::API do
       it 'accepts a valid request' do
         expect_any_instance_of(Debci::Job).to receive(:enqueue)
 
-        post format('/api/v1/test/%<suite>s/%<arch>s/mypackage', suite: suite, arch: arch)
+        post '/api/v1/test/%<suite>s/%<arch>s/mypackage' % { suite: suite, arch: arch }
 
         job = Debci::Job.last
-        expect(job.package).to eq('mypackage')
+        expect(job.package.name).to eq('mypackage')
         expect(job.suite).to eq(suite)
         expect(job.arch).to eq(arch)
         expect(job.requestor).to eq('theuser')
@@ -95,30 +97,38 @@ describe Debci::API do
 
       it 'enqueues with priority' do
         expect_any_instance_of(Debci::Job).to receive(:enqueue).with(Integer)
-        post format('/api/v1/test/%<suite>s/%<arch>s/mypackage', suite: suite, arch: arch)
+        post '/api/v1/test/%<suite>s/%<arch>s/mypackage' % { suite: suite, arch: arch, priority: 8 }
       end
 
       it 'rejects blacklisted package' do
         allow_any_instance_of(Debci::Blacklist).to receive(:include?)
           .with('mypackage', suite: suite, arch: arch).and_return(true)
-        post format('/api/v1/test/%<suite>s/%<arch>s/mypackage', suite: suite, arch: arch)
+        post '/api/v1/test/%<suite>s/%<arch>s/mypackage' % { suite: suite, arch: arch }
         expect(last_response.status).to eq(400)
       end
 
       it 'rejects invalid package names' do
         jobs = Debci::Job.count
-        post format('/api/v1/test/%<suite>s/%<arch>s/foo=bar', suite: suite, arch: arch)
+        post '/api/v1/test/%<suite>s/%<arch>s/foo=bar' % { suite: suite, arch: arch }
         expect(last_response.status).to eq(400)
         expect(Debci::Job.count).to eq(jobs)
       end
 
       it 'rejects unknown arch' do
-        post format('/api/v1/test/%<suite>s/%<arch>s/mypackage', suite: suite, arch: 'xyz')
+        post '/api/v1/test/%<suite>s/%<arch>s/mypackage' % { suite: suite, arch: 'xyz' }
         expect(last_response.status).to eq(400)
       end
 
       it 'rejects unknown suite' do
-        post format('/api/v1/test/%<suite>s/%<arch>s/mypackage', suite: 'nonexistingsuite', arch: arch)
+        post '/api/v1/test/%<suite>s/%<arch>s/mypackage' % { suite: 'nonexistingsuite', arch: arch }
+        expect(last_response.status).to eq(400)
+      end
+
+      it 'rejects invalid priorities' do
+        post '/api/v1/test/%<suite>s/%<arch>s/mypackage' % { suite: 'suite', arch: arch, priority: 0 }
+        expect(last_response.status).to eq(400)
+
+        post '/api/v1/test/%<suite>s/%<arch>s/mypackage' % { suite: 'suite', arch: arch, priority: 11 }
         expect(last_response.status).to eq(400)
       end
     end
@@ -127,10 +137,11 @@ describe Debci::API do
       it 'accepts a valid request' do
         allow_any_instance_of(Debci::Job).to receive(:enqueue)
 
-        post format('/api/v1/test/%<suite>s/%<arch>s', suite: suite, arch: arch), tests: '[{"package": "package1"}, {"package": "package2"}]'
+        post '/api/v1/test/%<suite>s/%<arch>s' % { suite: suite, arch: arch }, tests: '[{"package": "package1"}, {"package": "package2"}]'
 
         %w[package1 package2].each do |pkg|
-          job = Debci::Job.where(package: pkg).last
+          package = Debci::Package.find_by!(name: pkg)
+          job = Debci::Job.where(package: package).last
           expect(job.suite).to eq(suite)
           expect(job.arch).to eq(arch)
           expect(job.requestor).to eq('theuser')
@@ -141,13 +152,13 @@ describe Debci::API do
 
       it 'rejects unknown arch' do
         expect_any_instance_of(Debci::Job).to_not receive(:enqueue)
-        post format('/api/v1/test/%<suite>s/%<arch>s', suite: suite, arch: 'xyz'), tests: '[{"package": "package1"}, {"package": "package2"}]'
+        post '/api/v1/test/%<suite>s/%<arch>s' % { suite: suite, arch: 'xyz' }, tests: '[{"package": "package1"}, {"package": "package2"}]'
         expect(last_response.status).to eq(400)
       end
 
       it 'rejects unknown suite' do
         expect_any_instance_of(Debci::Job).to_not receive(:enqueue)
-        post format('/api/v1/test/%<suite>s/%<arch>s', suite: 'nonexistingsuite', arch: arch), tests: '[{"package": "package1"}, {"package": "package2"}]'
+        post '/api/v1/test/%<suite>s/%<arch>s' % { suite: 'nonexistingsuite', arch: arch }, tests: '[{"package": "package1"}, {"package": "package2"}]'
         expect(last_response.status).to eq(400)
       end
 
@@ -157,32 +168,30 @@ describe Debci::API do
 
         expect_any_instance_of(Debci::Job).to receive(:enqueue).once
 
-        post format('/api/v1/test/%<suite>s/%<arch>s', suite: suite, arch: arch), tests: '[{"package": "package1"}, {"package": "package2"}]'
+        post '/api/v1/test/%<suite>s/%<arch>s' % { suite: suite, arch: arch }, tests: '[{"package": "package1"}, {"package": "package2"}]'
         expect(last_response.status).to eq(201)
 
-        job1 = Debci::Job.find_by(package: 'package1', suite: suite, arch: arch)
+        package1 = Debci::Package.find_by!(name: 'package1')
+        job1 = Debci::Job.find_by(package: package1, suite: suite, arch: arch)
         expect(job1.status).to eq('fail')
         expect(job1.date).to_not be_nil
 
-        job2 = Debci::Job.find_by(package: 'package2', suite: suite, arch: arch)
+        package2 = Debci::Package.find_by!(name: 'package2')
+        job2 = Debci::Job.find_by(package: package2, suite: suite, arch: arch)
         expect(job2.status).to be_nil
         expect(job2.date).to be_nil
       end
 
-      it 'marks invalid package names as failed right away' do
-        post format('/api/v1/test/%<suite>s/%<arch>s', suite: suite, arch: arch), tests: '[{"package": "package1"}, {"package": "foo=package2"}]'
-        expect(last_response.status).to eq(201)
-
-        job1 = Debci::Job.find_by(package: 'package1', suite: suite, arch: arch)
-        expect(job1.status).to be_nil
-
-        job2 = Debci::Job.find_by(package: 'foo=package2', suite: suite, arch: arch)
-        expect(job2.status).to eq('fail')
+      it 'rejects invalid package names right away' do
+        jobs = Debci::Job.count
+        post '/api/v1/test/%<suite>s/%<arch>s' % { suite: suite, arch: arch }, tests: '[{"package": "package1"}, {"package": "foo=package2"}]'
+        expect(last_response.status).to eq(400)
+        expect(Debci::Job.count).to eq(jobs)
       end
 
       it 'handles invalid JSON gracefully' do
         expect_any_instance_of(Debci::Job).to_not receive(:enqueue)
-        post format('/api/v1/test/%<suite>s/%<arch>s', suite: suite, arch: arch), tests: 'invalid json'
+        post '/api/v1/test/%<suite>s/%<arch>s' % { suite: suite, arch: arch }, tests: 'invalid json'
         expect(last_response.status).to eq(400)
       end
 
@@ -191,20 +200,22 @@ describe Debci::API do
       it 'handles trigger and pin' do
         expect_any_instance_of(Debci::Job).to receive(:enqueue)
 
-        post format('/api/v1/test/%<suite>s/%<arch>s', suite: suite, arch: arch), tests: File.read(test_file)
+        post '/api/v1/test/%<suite>s/%<arch>s' % { suite: suite, arch: arch }, tests: File.read(test_file)
         expect(last_response.status).to eq(201)
 
-        job = Debci::Job.find_by(suite: suite, arch: arch, package: 'package1')
+        package1 = Debci::Package.find_by(name: 'package1')
+        job = Debci::Job.find_by(suite: suite, arch: arch, package: package1)
         expect(job.trigger).to eq('foo/1.0')
         expect(job.pin_packages).to eq([['src:foo', 'unstable']])
       end
 
       it 'handles trigger and pin as a file upload' do
         expect_any_instance_of(Debci::Job).to receive(:enqueue)
-        post format('/api/v1/test/%<suite>s/%<arch>s', suite: suite, arch: arch), tests: Rack::Test::UploadedFile.new(test_file, 'application/json')
+        post '/api/v1/test/%<suite>s/%<arch>s' % { suite: suite, arch: arch }, tests: Rack::Test::UploadedFile.new(test_file, 'application/json')
         expect(last_response.status).to eq(201)
 
-        job = Debci::Job.find_by(suite: suite, arch: arch, package: 'package1')
+        package1 = Debci::Package.find_by(name: 'package1')
+        job = Debci::Job.find_by(suite: suite, arch: arch, package: package1)
         expect(job.trigger).to eq('foo/1.0')
         expect(job.pin_packages).to eq([['src:foo', 'unstable']])
       end
@@ -216,7 +227,7 @@ describe Debci::API do
         expect(Debci::Job).to receive(:create!).with(anything).twice.and_return(job)
         expect(job).to receive(:enqueue).and_raise(Exception)
         expect do
-          post format('/api/v1/test/%<suite>s/%<arch>s', suite: suite, arch: arch), tests: Rack::Test::UploadedFile.new(batch_test_file, 'application/json')
+          post '/api/v1/test/%<suite>s/%<arch>s' % { suite: suite, arch: arch }, tests: Rack::Test::UploadedFile.new(batch_test_file, 'application/json')
         end.to raise_error(Exception)
       end
     end
@@ -256,7 +267,19 @@ describe Debci::API do
     end
 
     it 'displays a user friendly page to authenticated users' do
-      get '/api/v1/retry/1', {}, 'SSL_CLIENT_S_DN_CN' => 'foo@bar.com'
+      package = Debci::Package.create!(name: 'mypackage')
+      user = 'myuser'
+      trigger = 'mypackage/0.0.1'
+      pin_packages = ['src:mypackage', 'unstable']
+      job = Debci::Job.create(
+        package: package,
+        suite: suite,
+        arch: arch,
+        requestor: user,
+        trigger: trigger,
+        pin_packages: pin_packages
+      )
+      get "/api/v1/retry/#{job.id}", {}, 'SSL_CLIENT_S_DN_CN' => 'foo@bar.com'
       expect(last_response.status).to eq(200)
       expect(last_response.content_type).to match('text/html')
     end
@@ -268,7 +291,7 @@ describe Debci::API do
     end
 
     it 'can retrigger a valid request with key' do
-      package = 'mypackage'
+      package = Debci::Package.create!(name: 'mypackage')
       user = 'myuser'
       trigger = 'mypackage/0.0.1'
       pin_packages = ['src:mypackage', 'unstable']
@@ -284,7 +307,7 @@ describe Debci::API do
       job_org = Debci::Job.last
 
       # Here we are going to retrigger it
-      key = Debci::Key.create!(user: 'theuser').key
+      key = Debci::Key.create!(user: theuser).key
       header 'Auth-Key', key
       post "/api/v1/retry/#{job_org.run_id}"
 
@@ -301,7 +324,7 @@ describe Debci::API do
     end
 
     it 'can retrigger a valid request with client certificate' do
-      package = 'mypackage'
+      package = Debci::Package.create!(name: 'mypackage')
       user = 'myuser'
       trigger = 'mypackage/0.0.1'
       pin_packages = ['src:mypackage', 'unstable']
@@ -326,7 +349,7 @@ describe Debci::API do
     end
 
     it 'rejects to retrigger an unknown run_id' do
-      key = Debci::Key.create!(user: 'theuser').key
+      key = Debci::Key.create!(user: theuser).key
       header 'Auth-Key', key
       post '/api/v1/retry/1'
 
